==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/ServerRevokeAccess.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.io;
using com.db4o;
namespace com.db4o.test {

   public class ServerRevokeAccess {
      
      public ServerRevokeAccess() : base() {
      }
      static internal String FILE = "ServerRevokeAccessTest.yap";
      
      public void test() {
         if (!Tester.isClientServer() && Tester.currentRunner.CLIENT_SERVER) {
            try {
               {
                  new File(FILE).delete();
                  ObjectServer server1 = Db4o.openServer(FILE, AllTests.SERVER_PORT);
                  String user1 = "hohohi";
                  String password1 = "hohoho";
                  server1.grantAccess(user1, password1);
                  ObjectContainer con1 = Db4o.openClient(AllTests.SERVER_HOSTNAME, AllTests.SERVER_PORT, user1, password1);
                  Tester.ensure(con1 != null);
                  con1.close();
                  server1.ext().revokeAccess(user1);
                  bool exceptionThrown1 = false;
                  try {
                     {
                        con1 = Db4o.openClient(AllTests.SERVER_HOSTNAME, AllTests.SERVER_PORT, user1, password1);
                     }
                  }  catch (Exception e) {
                     {
                        exceptionThrown1 = true;
                     }
                  }
                  Tester.ensure(exceptionThrown1);
                  server1.close();
               }
            }  catch (Exception e) {
               {
                  j4o.lang.JavaSystem.printStackTrace(e);
               }
            }
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/ServerRevokeAccess.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using j4o.io;
using com.db4o;
namespace com.db4o.test {

   public class ServerRevokeAccess {
      
      public ServerRevokeAccess() : base() {
      }
      static internal String FILE = "ServerRevokeAccessTest.yap";
      
      public void Test() {
         if (!Tester.IsClientServer() && Tester.currentRunner.CLIENT_SERVER) {
            try {
               {
                  new File(FILE).Delete();
                  ObjectServer server1 = Db4o.OpenServer(FILE, AllTests.SERVER_PORT);
                  String user1 = "hohohi";
                  String password1 = "hohoho";
                  server1.GrantAccess(user1, password1);
                  ObjectContainer con1 = Db4o.OpenClient(AllTests.SERVER_HOSTNAME, AllTests.SERVER_PORT, user1, password1);
                  Tester.Ensure(con1 != null);
                  con1.Close();
                  server1.Ext().RevokeAccess(user1);
                  bool exceptionThrown1 = false;
                  try {
                     {
                        con1 = Db4o.OpenClient(AllTests.SERVER_HOSTNAME, AllTests.SERVER_PORT, user1, password1);
                     }
                  }  catch (Exception e) {
                     {
                        exceptionThrown1 = true;
                     }
                  }
                  Tester.Ensure(exceptionThrown1);
                  server1.Close();
               }
            }  catch (Exception e) {
               {
                  j4o.lang.JavaSystem.PrintStackTrace(e);
               }
            }
         }
      }
   }
}
